# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/inc_qua.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/inc_qua.proto',
  package='qm.grpc.qua',
  syntax='proto3',
  serialized_options=b'P\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13qm/pb/inc_qua.proto\x12\x0bqm.grpc.qua\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1aqm/pb/inc_qua_config.proto\"\xd3o\n\nQuaProgram\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfig\x12\x38\n\tdynConfig\x18\x02 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.DynamicConfig\x12.\n\x06script\x18\x05 \x01(\x0b\x32\x1e.qm.grpc.qua.QuaProgram.Script\x12@\n\x0f\x63ompilerOptions\x18\x06 \x01(\x0b\x32\'.qm.grpc.qua.QuaProgram.CompilerOptions\x12\x36\n\x0eresultAnalysis\x18\x07 \x01(\x0b\x32\x1e.qm.grpc.qua.QuaResultAnalysis\x1a\xd2\x01\n\x0f\x43ompilerOptions\x12.\n\"useExperimentalCalculationCompiler\x18\x01 \x01(\x08\x42\x02\x18\x01\x12&\n\x1aoptimizeMergeCodeExecution\x18\x02 \x01(\x08\x42\x02\x18\x01\x12%\n\x19optimizeWriteReadCommands\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x1d\n\x11skipOptimizations\x18\x04 \x03(\tB\x02\x18\x01\x12\x12\n\x06strict\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\r\n\x05\x66lags\x18\x06 \x03(\t\x1a\x7f\n\x06Script\x12\x39\n\tvariables\x18\x01 \x03(\x0b\x32&.qm.grpc.qua.QuaProgram.VarDeclaration\x12:\n\x04\x62ody\x18\n \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x1a\xb6\x01\n\x0eVarDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.qm.grpc.qua.QuaProgram.Type\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x38\n\x05value\x18\x04 \x03(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpression\x12\x0b\n\x03\x64im\x18\x05 \x01(\x05\x12\x15\n\risInputStream\x18\x06 \x01(\x08\x1a\x34\n\x17QuantumElementReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a+\n\x0ePulseReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x37\n\x1aIntegrationWeightReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x85\x0b\n\x0c\x41nyStatement\x12\x35\n\x04play\x18\x01 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.PlayStatementH\x00\x12;\n\x07measure\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.MeasureStatementH\x00\x12\x35\n\x04wait\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.WaitStatementH\x00\x12\x35\n\x04sync\x18\x04 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.SyncStatementH\x00\x12\x31\n\x02if\x18\x05 \x01(\x0b\x32#.qm.grpc.qua.QuaProgram.IfStatementH\x00\x12=\n\x06\x61ssign\x18\x06 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AssignmentStatementH\x00\x12\x33\n\x03\x66or\x18\x07 \x01(\x0b\x32$.qm.grpc.qua.QuaProgram.ForStatementH\x00\x12\x33\n\x03rus\x18\x08 \x01(\x0b\x32$.qm.grpc.qua.QuaProgram.RusStatementH\x00\x12\x37\n\x05\x61lign\x18\t \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.AlignStatementH\x00\x12K\n\x0fupdateFrequency\x18\n \x01(\x0b\x32\x30.qm.grpc.qua.QuaProgram.UpdateFrequencyStatementH\x00\x12?\n\tzRotation\x18\x0b \x01(\x0b\x32*.qm.grpc.qua.QuaProgram.ZRotationStatementH\x00\x12\x37\n\x05pause\x18\x0c \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PauseStatementH\x00\x12\x35\n\x04save\x18\r \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.SaveStatementH\x00\x12;\n\x07\x66orEach\x18\x0e \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.ForEachStatementH\x00\x12I\n\x0ewaitForTrigger\x18\x0f \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.WaitForTriggerStatementH\x00\x12\x35\n\x04qrun\x18\x10 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.QRunStatementH\x00\x12M\n\x10updateCorrection\x18\x11 \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.UpdateCorrectionStatementH\x00\x12\x41\n\nresetPhase\x18\x12 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.ResetPhaseStatementH\x00\x12\x41\n\nrampToZero\x18\x13 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.RampToZeroStatementH\x00\x12\x41\n\nresetFrame\x18\x14 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.ResetFrameStatementH\x00\x12\x43\n\x0bsetDcOffset\x18\x15 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.SetDcOffsetStatementH\x00\x12Q\n\x12\x61\x64vanceInputStream\x18\x16 \x01(\x0b\x32\x33.qm.grpc.qua.QuaProgram.AdvanceInputStreamStatementH\x00\x42\x11\n\x0fstatement_oneof\x1a\x80\x02\n\rAmpMultiplier\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x37\n\x02v0\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v1\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v2\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02v3\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x8f\x01\n\x13RampToZeroStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12.\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aT\n\tRampPulse\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\xe4\x02\n\x05\x43hirp\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x41\n\nscalarRate\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionH\x00\x12\x42\n\tarrayRate\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x12\x32\n\x05units\x18\x03 \x01(\x0e\x32#.qm.grpc.qua.QuaProgram.Chirp.Units\x12\r\n\x05times\x18\x04 \x03(\r\x12\x15\n\rcontinueChirp\x18\x05 \x01(\x08\"e\n\x05Units\x12\x10\n\x0cHzPerNanoSec\x10\x00\x12\x11\n\rmHzPerNanoSec\x10\x01\x12\x11\n\ruHzPerNanoSec\x10\x02\x12\x11\n\rnHzPerNanoSec\x10\x03\x12\x11\n\rpHzPerNanoSec\x10\x04\x42\x06\n\x04rate\x1a\xcc\x04\n\rPlayStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x39\n\x05pulse\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReferenceB\x02\x18\x01\x12<\n\nnamedPulse\x18\x07 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReferenceH\x00\x12\x36\n\trampPulse\x18\x08 \x01(\x0b\x32!.qm.grpc.qua.QuaProgram.RampPulseH\x00\x12\x32\n\x03\x61mp\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.AmpMultiplier\x12=\n\x08\x64uration\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12>\n\tcondition\x18\x05 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x13\n\x0btargetInput\x18\x06 \x01(\t\x12,\n\x05\x63hirp\x18\t \x01(\x0b\x32\x1d.qm.grpc.qua.QuaProgram.Chirp\x12=\n\x08truncate\x18\n \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionB\x0b\n\tpulseType\x1a\xaf\x02\n\x18UpdateFrequencyStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x45\n\x05units\x18\x03 \x01(\x0e\x32\x36.qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.Units\x12\x11\n\tkeepPhase\x18\x04 \x01(\x08\"3\n\x05Units\x12\x06\n\x02Hz\x10\x00\x12\x07\n\x03mHz\x10\x01\x12\x07\n\x03uHz\x10\x02\x12\x07\n\x03nHz\x10\x03\x12\x07\n\x03pHz\x10\x04\x1a\xb7\x01\n\x14SetDcOffsetStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x18\n\x10qeInputReference\x18\x02 \x01(\t\x12;\n\x06offset\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x9a\x01\n\x12ZRotationStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x03 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a_\n\x13ResetFrameStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x02 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1aZ\n\x0e\x41lignStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1a\x9d\x01\n\x0eMeasureProcess\x12>\n\x06\x61nalog\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.AnalogMeasureProcessH\x00\x12@\n\x07\x64igital\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.DigitalMeasureProcessH\x00\x42\t\n\x07process\x1a\xe4\x0e\n\x14\x41nalogMeasureProcess\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12W\n\x0f\x62\x61reIntegration\x18\x01 \x01(\x0b\x32<.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegrationH\x00\x12Y\n\x10\x64\x65modIntegration\x18\x02 \x01(\x0b\x32=.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegrationH\x00\x12U\n\x0erawTimeTagging\x18\x03 \x01(\x0b\x32;.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTaggingH\x00\x12_\n\x13\x64ualBareIntegration\x18\x04 \x01(\x0b\x32@.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegrationH\x00\x12\x61\n\x14\x64ualDemodIntegration\x18\x05 \x01(\x0b\x32\x41.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegrationH\x00\x12]\n\x12highResTimeTagging\x18\x06 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTaggingH\x00\x1a\xae\x01\n\x0f\x42\x61reIntegration\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\x96\x02\n\x13\x44ualBareIntegration\x12H\n\x0cintegration1\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12H\n\x0cintegration2\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x16\n\x0e\x65lementOutput1\x18\t \x01(\t\x12\x16\n\x0e\x65lementOutput2\x18\n \x01(\t\x1a\xaf\x01\n\x10\x44\x65modIntegration\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\x97\x02\n\x14\x44ualDemodIntegration\x12H\n\x0cintegration1\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12H\n\x0cintegration2\x18\x02 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12;\n\x06target\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnalogProcessTarget\x12\x16\n\x0e\x65lementOutput1\x18\t \x01(\t\x12\x16\n\x0e\x65lementOutput2\x18\n \x01(\t\x1a\xb4\x01\n\x0eRawTimeTagging\x12=\n\x06target\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x12\x15\n\relementOutput\x18\t \x01(\t\x1a\xb8\x01\n\x12HighResTimeTagging\x12=\n\x06target\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x12\x15\n\relementOutput\x18\t \x01(\tB\t\n\x07process\x1a\xf9\x03\n\x15\x44igitalMeasureProcess\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12V\n\x0erawTimeTagging\x18\x01 \x01(\x0b\x32<.qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTaggingH\x00\x12J\n\x08\x63ounting\x18\x02 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.DigitalMeasureProcess.CountingH\x00\x1a\xb4\x01\n\x0eRawTimeTagging\x12\x15\n\relementOutput\x18\x01 \x01(\t\x12=\n\x06target\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12;\n\ttargetLen\x18\x03 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x04 \x01(\x05\x1am\n\x08\x43ounting\x12\x16\n\x0e\x65lementOutputs\x18\x01 \x03(\t\x12\x38\n\x06target\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12\x0f\n\x07maxTime\x18\x03 \x01(\x05\x42\t\n\x07process\x1a\xb8\x06\n\x13\x41nalogProcessTarget\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12X\n\rscalarProcess\x18\x01 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTargetH\x00\x12X\n\rvectorProcess\x18\x02 \x01(\x0b\x32?.qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTargetH\x00\x1a\xa2\x01\n\x13ScalarProcessTarget\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a\xa3\x01\n\x13VectorProcessTarget\x12<\n\x05\x61rray\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12N\n\x0ctimeDivision\x18\x02 \x01(\x0b\x32\x38.qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision\x1a\x83\x02\n\x0cTimeDivision\x12\x43\n\x06sliced\x18\x02 \x01(\x0b\x32\x31.qm.grpc.qua.QuaProgram.AnalogTimeDivision.SlicedH\x00\x12M\n\x0b\x61\x63\x63umulated\x18\x03 \x01(\x0b\x32\x36.qm.grpc.qua.QuaProgram.AnalogTimeDivision.AccumulatedH\x00\x12O\n\x0cmovingWindow\x18\x04 \x01(\x0b\x32\x37.qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindowH\x00\x42\x0e\n\x0ctimeDivisionB\x0f\n\rprocessTarget\x1a\xc8\x01\n\x12\x41nalogTimeDivision\x1a.\n\x06Sliced\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x1a\x33\n\x0b\x41\x63\x63umulated\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x1aM\n\x0cMovingWindow\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x17\n\x0fsamplesPerChunk\x18\x01 \x01(\x05\x12\x17\n\x0f\x63hunksPerWindow\x18\x02 \x01(\x05\x1a\x8b\x03\n\rMeasureOutput\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12G\n\x0bintegration\x18\x01 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.IntegrationWeightReference\x12>\n\x08variable\x18\x02 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12\x0e\n\x06output\x18\x03 \x01(\t\x12<\n\x06target\x18\x04 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.MeasureOutput.Target\x1a\x95\x01\n\x06Target\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a\xd7\x02\n\x10MeasureStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x35\n\x05pulse\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReference\x12\x32\n\x03\x61mp\x18\x03 \x01(\x0b\x32%.qm.grpc.qua.QuaProgram.AmpMultiplier\x12:\n\x07outputs\x18\x04 \x03(\x0b\x32%.qm.grpc.qua.QuaProgram.MeasureOutputB\x02\x18\x01\x12\x10\n\x08streamAs\x18\x05 \x01(\t\x12@\n\x10measureProcesses\x18\x07 \x03(\x0b\x32&.qm.grpc.qua.QuaProgram.MeasureProcess\x1a\x94\x01\n\rWaitStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x39\n\x04time\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\xe5\x02\n\x17WaitForTriggerStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12;\n\x0bpulseToPlay\x18\x02 \x01(\x0b\x32&.qm.grpc.qua.QuaProgram.PulseReference\x12/\n\rglobalTrigger\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12V\n\relementOutput\x18\x04 \x01(\x0b\x32=.qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutputH\x00\x1a\x30\n\rElementOutput\x12\x0f\n\x07\x65lement\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\tB\x08\n\x06source\x1a\x9d\x01\n\x19UpdateCorrectionStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x36\n\ncorrection\x18\x02 \x01(\x0b\x32\".qm.grpc.qua.QuaProgram.Correction\x1a_\n\x13ResetPhaseStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12;\n\x02qe\x18\x01 \x01(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x1a\xfd\x01\n\nCorrection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x12\x37\n\x02\x63\x30\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x31\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x32\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x37\n\x02\x63\x33\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x1a\x1c\n\rSyncStatement\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x01\n\x06\x45lseIf\x12>\n\tcondition\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x93\x02\n\x0bIfStatement\x12>\n\tcondition\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x04\x65lse\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12/\n\x07\x65lseifs\x18\x04 \x03(\x0b\x32\x1e.qm.grpc.qua.QuaProgram.ElseIf\x12\x0e\n\x06unsafe\x18\x05 \x01(\x08\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x02\n\x0c\x46orStatement\x12:\n\x04init\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12<\n\x06update\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x04\x62ody\x18\x04 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1aX\n\rQRunStatement\x12:\n\x04\x62ody\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xbb\x02\n\x10\x46orEachStatement\x12M\n\x08iterator\x18\x01 \x03(\x0b\x32;.qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x8e\x01\n\x12VariableWithValues\x12:\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpression\x12<\n\x05\x61rray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x1a\xd7\x01\n\x0cRusStatement\x12=\n\x07\x64oBlock\x18\x01 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12?\n\tfailBlock\x18\x02 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.StatementsCollection\x12:\n\x05until\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x91\x03\n\x13\x41ssignmentStatement\x12>\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12?\n\nexpression\x18\x02 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x10\n\x04save\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x42\n\x06target\x18\x04 \x01(\x0b\x32\x32.qm.grpc.qua.QuaProgram.AssignmentStatement.Target\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x95\x01\n\x06Target\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x42\x08\n\x06target\x1a[\n\x0ePauseStatement\x12<\n\x03qes\x18\x01 \x03(\x0b\x32/.qm.grpc.qua.QuaProgram.QuantumElementReference\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xfd\x02\n\rSaveStatement\x12>\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionB\x02\x18\x01\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12<\n\x06source\x18\x03 \x01(\x0b\x32,.qm.grpc.qua.QuaProgram.SaveStatement.Source\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xd3\x01\n\x06Source\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x43\n\tarrayCell\x18\x02 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x12<\n\x07literal\x18\x03 \x01(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpressionH\x00\x42\x08\n\x06source\x1aP\n\x14StatementsCollection\x12\x38\n\nstatements\x18\x01 \x03(\x0b\x32$.qm.grpc.qua.QuaProgram.AnyStatement\x1a\xbb\x03\n\x13\x41nyScalarExpression\x12<\n\x08variable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12<\n\x07literal\x18\x02 \x01(\x0b\x32).qm.grpc.qua.QuaProgram.LiteralExpressionH\x00\x12\x43\n\x0f\x62inaryOperation\x18\x03 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.BinaryExpressionH\x00\x12\x43\n\tarrayCell\x18\x04 \x01(\x0b\x32..qm.grpc.qua.QuaProgram.ArrayCellRefExpressionH\x00\x12\x44\n\x0b\x61rrayLength\x18\x05 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayLengthExpressionH\x00\x12\x44\n\x0blibFunction\x18\x06 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.LibFunctionExpressionH\x00\x42\x12\n\x10\x65xpression_oneof\x1a\xb8\x02\n\x15LibFunctionExpression\x12\x14\n\x0c\x66unctionName\x18\x01 \x01(\t\x12I\n\targuments\x18\x02 \x03(\x0b\x32\x36.qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument\x12\x13\n\x0blibraryName\x18\x03 \x01(\t\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\x9b\x01\n\x08\x41rgument\x12=\n\x06scalar\x18\x01 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpressionH\x00\x12>\n\x05\x61rray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x42\x10\n\x0e\x61rgument_oneof\x1a\xc4\x01\n\x1b\x41\x64vanceInputStreamStatement\x12\x42\n\x0estreamVariable\x18\x01 \x01(\x0b\x32(.qm.grpc.qua.QuaProgram.VarRefExpressionH\x00\x12\x44\n\x0bstreamArray\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpressionH\x00\x12\x0b\n\x03loc\x18\x64 \x01(\tB\x0e\n\x0cstream_oneof\x1a\x62\n\x15\x41rrayLengthExpression\x12<\n\x05\x61rray\x18\x01 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1aV\n\x10VarRefExpression\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x12\n\x08ioNumber\x18\x03 \x01(\x05H\x00\x12\x0b\n\x03loc\x18\x64 \x01(\tB\x0b\n\tvar_oneofJ\x04\x08\x01\x10\x02\x1a\x38\n\x15\x41rrayVarRefExpression\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03loc\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02\x1a\xa8\x01\n\x16\x41rrayCellRefExpression\x12?\n\x08\x61rrayVar\x18\x02 \x01(\x0b\x32-.qm.grpc.qua.QuaProgram.ArrayVarRefExpression\x12:\n\x05index\x18\x03 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02\x1a[\n\x11LiteralExpression\x12\r\n\x05value\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.qm.grpc.qua.QuaProgram.Type\x12\x0b\n\x03loc\x18\x64 \x01(\t\x1a\xe9\x02\n\x10\x42inaryExpression\x12\x43\n\x02op\x18\x01 \x01(\x0e\x32\x37.qm.grpc.qua.QuaProgram.BinaryExpression.BinaryOperator\x12\x39\n\x04left\x18\x04 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12:\n\x05right\x18\x05 \x01(\x0b\x32+.qm.grpc.qua.QuaProgram.AnyScalarExpression\x12\x0b\n\x03loc\x18\x64 \x01(\t\"\x8b\x01\n\x0e\x42inaryOperator\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\x07\n\x03SUB\x10\x01\x12\x08\n\x04MULT\x10\x02\x12\x07\n\x03\x44IV\x10\x03\x12\x07\n\x03\x41ND\x10\x04\x12\x06\n\x02OR\x10\x05\x12\x07\n\x03XOR\x10\x06\x12\x06\n\x02LT\x10\x07\x12\x07\n\x03LET\x10\x08\x12\x06\n\x02GT\x10\t\x12\x07\n\x03GET\x10\n\x12\x06\n\x02\x45Q\x10\x0b\x12\x07\n\x03SHL\x10\x0c\x12\x07\n\x03SHR\x10\r\x1aG\n\rDynamicConfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12%\n\x04root\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"#\n\x04Type\x12\x07\n\x03INT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04REAL\x10\x02\"O\n\x11QuaResultAnalysis\x12\x0f\n\x07version\x18\x01 \x01(\r\x12)\n\x05model\x18\x03 \x03(\x0b\x32\x1a.google.protobuf.ListValueB\x02P\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,qm_dot_pb_dot_inc__qua__config__pb2.DESCRIPTOR,])



_QUAPROGRAM_CHIRP_UNITS = _descriptor.EnumDescriptor(
  name='Units',
  full_name='qm.grpc.qua.QuaProgram.Chirp.Units',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HzPerNanoSec', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='mHzPerNanoSec', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='uHzPerNanoSec', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nHzPerNanoSec', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pHzPerNanoSec', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3283,
  serialized_end=3384,
)
_sym_db.RegisterEnumDescriptor(_QUAPROGRAM_CHIRP_UNITS)

_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS = _descriptor.EnumDescriptor(
  name='Units',
  full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.Units',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Hz', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='mHz', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='uHz', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nHz', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pHz', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4238,
  serialized_end=4289,
)
_sym_db.RegisterEnumDescriptor(_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS)

_QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR = _descriptor.EnumDescriptor(
  name='BinaryOperator',
  full_name='qm.grpc.qua.QuaProgram.BinaryExpression.BinaryOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIV', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AND', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LET', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GET', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQ', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHL', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHR', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14198,
  serialized_end=14337,
)
_sym_db.RegisterEnumDescriptor(_QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR)

_QUAPROGRAM_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='qm.grpc.qua.QuaProgram.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14412,
  serialized_end=14447,
)
_sym_db.RegisterEnumDescriptor(_QUAPROGRAM_TYPE)


_QUAPROGRAM_COMPILEROPTIONS = _descriptor.Descriptor(
  name='CompilerOptions',
  full_name='qm.grpc.qua.QuaProgram.CompilerOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='useExperimentalCalculationCompiler', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.useExperimentalCalculationCompiler', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizeMergeCodeExecution', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.optimizeMergeCodeExecution', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimizeWriteReadCommands', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.optimizeWriteReadCommands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skipOptimizations', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.skipOptimizations', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.strict', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='qm.grpc.qua.QuaProgram.CompilerOptions.flags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=656,
)

_QUAPROGRAM_SCRIPT = _descriptor.Descriptor(
  name='Script',
  full_name='qm.grpc.qua.QuaProgram.Script',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='qm.grpc.qua.QuaProgram.Script.variables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.Script.body', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=785,
)

_QUAPROGRAM_VARDECLARATION = _descriptor.Descriptor(
  name='VarDeclaration',
  full_name='qm.grpc.qua.QuaProgram.VarDeclaration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.value', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.dim', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isInputStream', full_name='qm.grpc.qua.QuaProgram.VarDeclaration.isInputStream', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=970,
)

_QUAPROGRAM_QUANTUMELEMENTREFERENCE = _descriptor.Descriptor(
  name='QuantumElementReference',
  full_name='qm.grpc.qua.QuaProgram.QuantumElementReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.QuantumElementReference.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.QuantumElementReference.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1024,
)

_QUAPROGRAM_PULSEREFERENCE = _descriptor.Descriptor(
  name='PulseReference',
  full_name='qm.grpc.qua.QuaProgram.PulseReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.PulseReference.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.PulseReference.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1069,
)

_QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE = _descriptor.Descriptor(
  name='IntegrationWeightReference',
  full_name='qm.grpc.qua.QuaProgram.IntegrationWeightReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.IntegrationWeightReference.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.IntegrationWeightReference.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1126,
)

_QUAPROGRAM_ANYSTATEMENT = _descriptor.Descriptor(
  name='AnyStatement',
  full_name='qm.grpc.qua.QuaProgram.AnyStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='play', full_name='qm.grpc.qua.QuaProgram.AnyStatement.play', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measure', full_name='qm.grpc.qua.QuaProgram.AnyStatement.measure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait', full_name='qm.grpc.qua.QuaProgram.AnyStatement.wait', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sync', full_name='qm.grpc.qua.QuaProgram.AnyStatement.sync', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='if', full_name='qm.grpc.qua.QuaProgram.AnyStatement.if', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assign', full_name='qm.grpc.qua.QuaProgram.AnyStatement.assign', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for', full_name='qm.grpc.qua.QuaProgram.AnyStatement.for', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rus', full_name='qm.grpc.qua.QuaProgram.AnyStatement.rus', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='align', full_name='qm.grpc.qua.QuaProgram.AnyStatement.align', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateFrequency', full_name='qm.grpc.qua.QuaProgram.AnyStatement.updateFrequency', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zRotation', full_name='qm.grpc.qua.QuaProgram.AnyStatement.zRotation', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause', full_name='qm.grpc.qua.QuaProgram.AnyStatement.pause', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='save', full_name='qm.grpc.qua.QuaProgram.AnyStatement.save', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forEach', full_name='qm.grpc.qua.QuaProgram.AnyStatement.forEach', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waitForTrigger', full_name='qm.grpc.qua.QuaProgram.AnyStatement.waitForTrigger', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qrun', full_name='qm.grpc.qua.QuaProgram.AnyStatement.qrun', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updateCorrection', full_name='qm.grpc.qua.QuaProgram.AnyStatement.updateCorrection', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resetPhase', full_name='qm.grpc.qua.QuaProgram.AnyStatement.resetPhase', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rampToZero', full_name='qm.grpc.qua.QuaProgram.AnyStatement.rampToZero', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resetFrame', full_name='qm.grpc.qua.QuaProgram.AnyStatement.resetFrame', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setDcOffset', full_name='qm.grpc.qua.QuaProgram.AnyStatement.setDcOffset', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advanceInputStream', full_name='qm.grpc.qua.QuaProgram.AnyStatement.advanceInputStream', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='statement_oneof', full_name='qm.grpc.qua.QuaProgram.AnyStatement.statement_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1129,
  serialized_end=2542,
)

_QUAPROGRAM_AMPMULTIPLIER = _descriptor.Descriptor(
  name='AmpMultiplier',
  full_name='qm.grpc.qua.QuaProgram.AmpMultiplier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AmpMultiplier.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v0', full_name='qm.grpc.qua.QuaProgram.AmpMultiplier.v0', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v1', full_name='qm.grpc.qua.QuaProgram.AmpMultiplier.v1', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2', full_name='qm.grpc.qua.QuaProgram.AmpMultiplier.v2', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v3', full_name='qm.grpc.qua.QuaProgram.AmpMultiplier.v3', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2545,
  serialized_end=2801,
)

_QUAPROGRAM_RAMPTOZEROSTATEMENT = _descriptor.Descriptor(
  name='RampToZeroStatement',
  full_name='qm.grpc.qua.QuaProgram.RampToZeroStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.RampToZeroStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.RampToZeroStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='qm.grpc.qua.QuaProgram.RampToZeroStatement.duration', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2804,
  serialized_end=2947,
)

_QUAPROGRAM_RAMPPULSE = _descriptor.Descriptor(
  name='RampPulse',
  full_name='qm.grpc.qua.QuaProgram.RampPulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.RampPulse.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua.QuaProgram.RampPulse.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=3033,
)

_QUAPROGRAM_CHIRP = _descriptor.Descriptor(
  name='Chirp',
  full_name='qm.grpc.qua.QuaProgram.Chirp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.Chirp.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scalarRate', full_name='qm.grpc.qua.QuaProgram.Chirp.scalarRate', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayRate', full_name='qm.grpc.qua.QuaProgram.Chirp.arrayRate', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='units', full_name='qm.grpc.qua.QuaProgram.Chirp.units', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='times', full_name='qm.grpc.qua.QuaProgram.Chirp.times', index=4,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continueChirp', full_name='qm.grpc.qua.QuaProgram.Chirp.continueChirp', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUAPROGRAM_CHIRP_UNITS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rate', full_name='qm.grpc.qua.QuaProgram.Chirp.rate',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3036,
  serialized_end=3392,
)

_QUAPROGRAM_PLAYSTATEMENT = _descriptor.Descriptor(
  name='PlayStatement',
  full_name='qm.grpc.qua.QuaProgram.PlayStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.PlayStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.PlayStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulse', full_name='qm.grpc.qua.QuaProgram.PlayStatement.pulse', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namedPulse', full_name='qm.grpc.qua.QuaProgram.PlayStatement.namedPulse', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rampPulse', full_name='qm.grpc.qua.QuaProgram.PlayStatement.rampPulse', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amp', full_name='qm.grpc.qua.QuaProgram.PlayStatement.amp', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='qm.grpc.qua.QuaProgram.PlayStatement.duration', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='qm.grpc.qua.QuaProgram.PlayStatement.condition', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetInput', full_name='qm.grpc.qua.QuaProgram.PlayStatement.targetInput', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chirp', full_name='qm.grpc.qua.QuaProgram.PlayStatement.chirp', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncate', full_name='qm.grpc.qua.QuaProgram.PlayStatement.truncate', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='pulseType', full_name='qm.grpc.qua.QuaProgram.PlayStatement.pulseType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3395,
  serialized_end=3983,
)

_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT = _descriptor.Descriptor(
  name='UpdateFrequencyStatement',
  full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.value', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='units', full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.units', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepPhase', full_name='qm.grpc.qua.QuaProgram.UpdateFrequencyStatement.keepPhase', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3986,
  serialized_end=4289,
)

_QUAPROGRAM_SETDCOFFSETSTATEMENT = _descriptor.Descriptor(
  name='SetDcOffsetStatement',
  full_name='qm.grpc.qua.QuaProgram.SetDcOffsetStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.SetDcOffsetStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.SetDcOffsetStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qeInputReference', full_name='qm.grpc.qua.QuaProgram.SetDcOffsetStatement.qeInputReference', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.qua.QuaProgram.SetDcOffsetStatement.offset', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4292,
  serialized_end=4475,
)

_QUAPROGRAM_ZROTATIONSTATEMENT = _descriptor.Descriptor(
  name='ZRotationStatement',
  full_name='qm.grpc.qua.QuaProgram.ZRotationStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ZRotationStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.ZRotationStatement.qe', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua.QuaProgram.ZRotationStatement.value', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4478,
  serialized_end=4632,
)

_QUAPROGRAM_RESETFRAMESTATEMENT = _descriptor.Descriptor(
  name='ResetFrameStatement',
  full_name='qm.grpc.qua.QuaProgram.ResetFrameStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ResetFrameStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.ResetFrameStatement.qe', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4634,
  serialized_end=4729,
)

_QUAPROGRAM_ALIGNSTATEMENT = _descriptor.Descriptor(
  name='AlignStatement',
  full_name='qm.grpc.qua.QuaProgram.AlignStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AlignStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.AlignStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4731,
  serialized_end=4821,
)

_QUAPROGRAM_MEASUREPROCESS = _descriptor.Descriptor(
  name='MeasureProcess',
  full_name='qm.grpc.qua.QuaProgram.MeasureProcess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='analog', full_name='qm.grpc.qua.QuaProgram.MeasureProcess.analog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digital', full_name='qm.grpc.qua.QuaProgram.MeasureProcess.digital', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='process', full_name='qm.grpc.qua.QuaProgram.MeasureProcess.process',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4824,
  serialized_end=4981,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION = _descriptor.Descriptor(
  name='BareIntegration',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegration.integration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegration.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegration.elementOutput', index=2,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5580,
  serialized_end=5754,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION = _descriptor.Descriptor(
  name='DualBareIntegration',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integration1', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration.integration1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integration2', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration.integration2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration.target', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput1', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration.elementOutput1', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput2', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration.elementOutput2', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5757,
  serialized_end=6035,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION = _descriptor.Descriptor(
  name='DemodIntegration',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegration.integration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegration.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegration.elementOutput', index=2,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6038,
  serialized_end=6213,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION = _descriptor.Descriptor(
  name='DualDemodIntegration',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='integration1', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration.integration1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integration2', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration.integration2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration.target', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput1', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration.elementOutput1', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput2', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration.elementOutput2', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6216,
  serialized_end=6495,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING = _descriptor.Descriptor(
  name='RawTimeTagging',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetLen', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging.targetLen', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTime', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging.maxTime', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging.elementOutput', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6498,
  serialized_end=6678,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING = _descriptor.Descriptor(
  name='HighResTimeTagging',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetLen', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging.targetLen', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTime', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging.maxTime', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging.elementOutput', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6681,
  serialized_end=6865,
)

_QUAPROGRAM_ANALOGMEASUREPROCESS = _descriptor.Descriptor(
  name='AnalogMeasureProcess',
  full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bareIntegration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.bareIntegration', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='demodIntegration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.demodIntegration', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawTimeTagging', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.rawTimeTagging', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dualBareIntegration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.dualBareIntegration', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dualDemodIntegration', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.dualDemodIntegration', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highResTimeTagging', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.highResTimeTagging', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION, _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION, _QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION, _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION, _QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING, _QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='process', full_name='qm.grpc.qua.QuaProgram.AnalogMeasureProcess.process',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4984,
  serialized_end=6876,
)

_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING = _descriptor.Descriptor(
  name='RawTimeTagging',
  full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging.elementOutput', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetLen', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging.targetLen', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTime', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging.maxTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7082,
  serialized_end=7262,
)

_QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING = _descriptor.Descriptor(
  name='Counting',
  full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.Counting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elementOutputs', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.Counting.elementOutputs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.Counting.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTime', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.Counting.maxTime', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7264,
  serialized_end=7373,
)

_QUAPROGRAM_DIGITALMEASUREPROCESS = _descriptor.Descriptor(
  name='DigitalMeasureProcess',
  full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawTimeTagging', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.rawTimeTagging', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counting', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.counting', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING, _QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='process', full_name='qm.grpc.qua.QuaProgram.DigitalMeasureProcess.process',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6879,
  serialized_end=7384,
)

_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET = _descriptor.Descriptor(
  name='ScalarProcessTarget',
  full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTarget.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayCell', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTarget.arrayCell', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTarget.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7604,
  serialized_end=7766,
)

_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET = _descriptor.Descriptor(
  name='VectorProcessTarget',
  full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTarget.array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeDivision', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTarget.timeDivision', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7769,
  serialized_end=7932,
)

_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION = _descriptor.Descriptor(
  name='TimeDivision',
  full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sliced', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision.sliced', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulated', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision.accumulated', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movingWindow', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision.movingWindow', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='timeDivision', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision.timeDivision',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7935,
  serialized_end=8194,
)

_QUAPROGRAM_ANALOGPROCESSTARGET = _descriptor.Descriptor(
  name='AnalogProcessTarget',
  full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scalarProcess', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.scalarProcess', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vectorProcess', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.vectorProcess', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET, _QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET, _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='processTarget', full_name='qm.grpc.qua.QuaProgram.AnalogProcessTarget.processTarget',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7387,
  serialized_end=8211,
)

_QUAPROGRAM_ANALOGTIMEDIVISION_SLICED = _descriptor.Descriptor(
  name='Sliced',
  full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Sliced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Sliced.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samplesPerChunk', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Sliced.samplesPerChunk', index=1,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8236,
  serialized_end=8282,
)

_QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED = _descriptor.Descriptor(
  name='Accumulated',
  full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Accumulated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Accumulated.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samplesPerChunk', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.Accumulated.samplesPerChunk', index=1,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8284,
  serialized_end=8335,
)

_QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW = _descriptor.Descriptor(
  name='MovingWindow',
  full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindow.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samplesPerChunk', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindow.samplesPerChunk', index=1,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunksPerWindow', full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindow.chunksPerWindow', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8337,
  serialized_end=8414,
)

_QUAPROGRAM_ANALOGTIMEDIVISION = _descriptor.Descriptor(
  name='AnalogTimeDivision',
  full_name='qm.grpc.qua.QuaProgram.AnalogTimeDivision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_ANALOGTIMEDIVISION_SLICED, _QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED, _QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8214,
  serialized_end=8414,
)

_QUAPROGRAM_MEASUREOUTPUT_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='qm.grpc.qua.QuaProgram.MeasureOutput.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.Target.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayCell', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.Target.arrayCell', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.Target.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8663,
  serialized_end=8812,
)

_QUAPROGRAM_MEASUREOUTPUT = _descriptor.Descriptor(
  name='MeasureOutput',
  full_name='qm.grpc.qua.QuaProgram.MeasureOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integration', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.integration', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.variable', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.output', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.MeasureOutput.target', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_MEASUREOUTPUT_TARGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8417,
  serialized_end=8812,
)

_QUAPROGRAM_MEASURESTATEMENT = _descriptor.Descriptor(
  name='MeasureStatement',
  full_name='qm.grpc.qua.QuaProgram.MeasureStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulse', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.pulse', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amp', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.amp', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.outputs', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamAs', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.streamAs', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measureProcesses', full_name='qm.grpc.qua.QuaProgram.MeasureStatement.measureProcesses', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8815,
  serialized_end=9158,
)

_QUAPROGRAM_WAITSTATEMENT = _descriptor.Descriptor(
  name='WaitStatement',
  full_name='qm.grpc.qua.QuaProgram.WaitStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.WaitStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.WaitStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='qm.grpc.qua.QuaProgram.WaitStatement.time', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9161,
  serialized_end=9309,
)

_QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT = _descriptor.Descriptor(
  name='ElementOutput',
  full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutput.element', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutput.output', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9611,
  serialized_end=9659,
)

_QUAPROGRAM_WAITFORTRIGGERSTATEMENT = _descriptor.Descriptor(
  name='WaitForTriggerStatement',
  full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pulseToPlay', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.pulseToPlay', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='globalTrigger', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.globalTrigger', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementOutput', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.elementOutput', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='qm.grpc.qua.QuaProgram.WaitForTriggerStatement.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9312,
  serialized_end=9669,
)

_QUAPROGRAM_UPDATECORRECTIONSTATEMENT = _descriptor.Descriptor(
  name='UpdateCorrectionStatement',
  full_name='qm.grpc.qua.QuaProgram.UpdateCorrectionStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.UpdateCorrectionStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.UpdateCorrectionStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.qua.QuaProgram.UpdateCorrectionStatement.correction', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9672,
  serialized_end=9829,
)

_QUAPROGRAM_RESETPHASESTATEMENT = _descriptor.Descriptor(
  name='ResetPhaseStatement',
  full_name='qm.grpc.qua.QuaProgram.ResetPhaseStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ResetPhaseStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qua.QuaProgram.ResetPhaseStatement.qe', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9831,
  serialized_end=9926,
)

_QUAPROGRAM_CORRECTION = _descriptor.Descriptor(
  name='Correction',
  full_name='qm.grpc.qua.QuaProgram.Correction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.Correction.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c0', full_name='qm.grpc.qua.QuaProgram.Correction.c0', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c1', full_name='qm.grpc.qua.QuaProgram.Correction.c1', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c2', full_name='qm.grpc.qua.QuaProgram.Correction.c2', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c3', full_name='qm.grpc.qua.QuaProgram.Correction.c3', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9929,
  serialized_end=10182,
)

_QUAPROGRAM_SYNCSTATEMENT = _descriptor.Descriptor(
  name='SyncStatement',
  full_name='qm.grpc.qua.QuaProgram.SyncStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.SyncStatement.loc', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10184,
  serialized_end=10212,
)

_QUAPROGRAM_ELSEIF = _descriptor.Descriptor(
  name='ElseIf',
  full_name='qm.grpc.qua.QuaProgram.ElseIf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition', full_name='qm.grpc.qua.QuaProgram.ElseIf.condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.ElseIf.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ElseIf.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10215,
  serialized_end=10360,
)

_QUAPROGRAM_IFSTATEMENT = _descriptor.Descriptor(
  name='IfStatement',
  full_name='qm.grpc.qua.QuaProgram.IfStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition', full_name='qm.grpc.qua.QuaProgram.IfStatement.condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.IfStatement.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='else', full_name='qm.grpc.qua.QuaProgram.IfStatement.else', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elseifs', full_name='qm.grpc.qua.QuaProgram.IfStatement.elseifs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsafe', full_name='qm.grpc.qua.QuaProgram.IfStatement.unsafe', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.IfStatement.loc', index=5,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10363,
  serialized_end=10638,
)

_QUAPROGRAM_FORSTATEMENT = _descriptor.Descriptor(
  name='ForStatement',
  full_name='qm.grpc.qua.QuaProgram.ForStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='init', full_name='qm.grpc.qua.QuaProgram.ForStatement.init', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='qm.grpc.qua.QuaProgram.ForStatement.condition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='qm.grpc.qua.QuaProgram.ForStatement.update', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.ForStatement.body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ForStatement.loc', index=4,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10641,
  serialized_end=10914,
)

_QUAPROGRAM_QRUNSTATEMENT = _descriptor.Descriptor(
  name='QRunStatement',
  full_name='qm.grpc.qua.QuaProgram.QRunStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.QRunStatement.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.QRunStatement.loc', index=1,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10916,
  serialized_end=11004,
)

_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES = _descriptor.Descriptor(
  name='VariableWithValues',
  full_name='qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array', full_name='qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues.array', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11180,
  serialized_end=11322,
)

_QUAPROGRAM_FOREACHSTATEMENT = _descriptor.Descriptor(
  name='ForEachStatement',
  full_name='qm.grpc.qua.QuaProgram.ForEachStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iterator', full_name='qm.grpc.qua.QuaProgram.ForEachStatement.iterator', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='qm.grpc.qua.QuaProgram.ForEachStatement.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ForEachStatement.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11007,
  serialized_end=11322,
)

_QUAPROGRAM_RUSSTATEMENT = _descriptor.Descriptor(
  name='RusStatement',
  full_name='qm.grpc.qua.QuaProgram.RusStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='doBlock', full_name='qm.grpc.qua.QuaProgram.RusStatement.doBlock', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failBlock', full_name='qm.grpc.qua.QuaProgram.RusStatement.failBlock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='until', full_name='qm.grpc.qua.QuaProgram.RusStatement.until', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.RusStatement.loc', index=3,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11325,
  serialized_end=11540,
)

_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.Target.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayCell', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.Target.arrayCell', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.Target.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8663,
  serialized_end=8812,
)

_QUAPROGRAM_ASSIGNMENTSTATEMENT = _descriptor.Descriptor(
  name='AssignmentStatement',
  full_name='qm.grpc.qua.QuaProgram.AssignmentStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.expression', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='save', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.save', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.target', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AssignmentStatement.loc', index=4,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11543,
  serialized_end=11944,
)

_QUAPROGRAM_PAUSESTATEMENT = _descriptor.Descriptor(
  name='PauseStatement',
  full_name='qm.grpc.qua.QuaProgram.PauseStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='qes', full_name='qm.grpc.qua.QuaProgram.PauseStatement.qes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.PauseStatement.loc', index=1,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11946,
  serialized_end=12037,
)

_QUAPROGRAM_SAVESTATEMENT_SOURCE = _descriptor.Descriptor(
  name='Source',
  full_name='qm.grpc.qua.QuaProgram.SaveStatement.Source',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.SaveStatement.Source.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayCell', full_name='qm.grpc.qua.QuaProgram.SaveStatement.Source.arrayCell', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literal', full_name='qm.grpc.qua.QuaProgram.SaveStatement.Source.literal', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='qm.grpc.qua.QuaProgram.SaveStatement.Source.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12210,
  serialized_end=12421,
)

_QUAPROGRAM_SAVESTATEMENT = _descriptor.Descriptor(
  name='SaveStatement',
  full_name='qm.grpc.qua.QuaProgram.SaveStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.SaveStatement.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='qm.grpc.qua.QuaProgram.SaveStatement.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='qm.grpc.qua.QuaProgram.SaveStatement.source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.SaveStatement.loc', index=3,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_SAVESTATEMENT_SOURCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12040,
  serialized_end=12421,
)

_QUAPROGRAM_STATEMENTSCOLLECTION = _descriptor.Descriptor(
  name='StatementsCollection',
  full_name='qm.grpc.qua.QuaProgram.StatementsCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statements', full_name='qm.grpc.qua.QuaProgram.StatementsCollection.statements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12423,
  serialized_end=12503,
)

_QUAPROGRAM_ANYSCALAREXPRESSION = _descriptor.Descriptor(
  name='AnyScalarExpression',
  full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.variable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literal', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.literal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binaryOperation', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.binaryOperation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayCell', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.arrayCell', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrayLength', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.arrayLength', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='libFunction', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.libFunction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expression_oneof', full_name='qm.grpc.qua.QuaProgram.AnyScalarExpression.expression_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=12506,
  serialized_end=12949,
)

_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scalar', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument.scalar', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument.array', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='argument_oneof', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument.argument_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=13109,
  serialized_end=13264,
)

_QUAPROGRAM_LIBFUNCTIONEXPRESSION = _descriptor.Descriptor(
  name='LibFunctionExpression',
  full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='functionName', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.functionName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='libraryName', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.libraryName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.LibFunctionExpression.loc', index=3,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12952,
  serialized_end=13264,
)

_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT = _descriptor.Descriptor(
  name='AdvanceInputStreamStatement',
  full_name='qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamVariable', full_name='qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement.streamVariable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamArray', full_name='qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement.streamArray', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='stream_oneof', full_name='qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement.stream_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=13267,
  serialized_end=13463,
)

_QUAPROGRAM_ARRAYLENGTHEXPRESSION = _descriptor.Descriptor(
  name='ArrayLengthExpression',
  full_name='qm.grpc.qua.QuaProgram.ArrayLengthExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='qm.grpc.qua.QuaProgram.ArrayLengthExpression.array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ArrayLengthExpression.loc', index=1,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13465,
  serialized_end=13563,
)

_QUAPROGRAM_VARREFEXPRESSION = _descriptor.Descriptor(
  name='VarRefExpression',
  full_name='qm.grpc.qua.QuaProgram.VarRefExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.VarRefExpression.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ioNumber', full_name='qm.grpc.qua.QuaProgram.VarRefExpression.ioNumber', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.VarRefExpression.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='var_oneof', full_name='qm.grpc.qua.QuaProgram.VarRefExpression.var_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=13565,
  serialized_end=13651,
)

_QUAPROGRAM_ARRAYVARREFEXPRESSION = _descriptor.Descriptor(
  name='ArrayVarRefExpression',
  full_name='qm.grpc.qua.QuaProgram.ArrayVarRefExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='qm.grpc.qua.QuaProgram.ArrayVarRefExpression.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ArrayVarRefExpression.loc', index=1,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13653,
  serialized_end=13709,
)

_QUAPROGRAM_ARRAYCELLREFEXPRESSION = _descriptor.Descriptor(
  name='ArrayCellRefExpression',
  full_name='qm.grpc.qua.QuaProgram.ArrayCellRefExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arrayVar', full_name='qm.grpc.qua.QuaProgram.ArrayCellRefExpression.arrayVar', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='qm.grpc.qua.QuaProgram.ArrayCellRefExpression.index', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.ArrayCellRefExpression.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13712,
  serialized_end=13880,
)

_QUAPROGRAM_LITERALEXPRESSION = _descriptor.Descriptor(
  name='LiteralExpression',
  full_name='qm.grpc.qua.QuaProgram.LiteralExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qua.QuaProgram.LiteralExpression.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='qm.grpc.qua.QuaProgram.LiteralExpression.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.LiteralExpression.loc', index=2,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13882,
  serialized_end=13973,
)

_QUAPROGRAM_BINARYEXPRESSION = _descriptor.Descriptor(
  name='BinaryExpression',
  full_name='qm.grpc.qua.QuaProgram.BinaryExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='qm.grpc.qua.QuaProgram.BinaryExpression.op', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='qm.grpc.qua.QuaProgram.BinaryExpression.left', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='qm.grpc.qua.QuaProgram.BinaryExpression.right', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc', full_name='qm.grpc.qua.QuaProgram.BinaryExpression.loc', index=3,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13976,
  serialized_end=14337,
)

_QUAPROGRAM_DYNAMICCONFIG = _descriptor.Descriptor(
  name='DynamicConfig',
  full_name='qm.grpc.qua.QuaProgram.DynamicConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.qua.QuaProgram.DynamicConfig.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root', full_name='qm.grpc.qua.QuaProgram.DynamicConfig.root', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14339,
  serialized_end=14410,
)

_QUAPROGRAM = _descriptor.Descriptor(
  name='QuaProgram',
  full_name='qm.grpc.qua.QuaProgram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='qm.grpc.qua.QuaProgram.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynConfig', full_name='qm.grpc.qua.QuaProgram.dynConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script', full_name='qm.grpc.qua.QuaProgram.script', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compilerOptions', full_name='qm.grpc.qua.QuaProgram.compilerOptions', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resultAnalysis', full_name='qm.grpc.qua.QuaProgram.resultAnalysis', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUAPROGRAM_COMPILEROPTIONS, _QUAPROGRAM_SCRIPT, _QUAPROGRAM_VARDECLARATION, _QUAPROGRAM_QUANTUMELEMENTREFERENCE, _QUAPROGRAM_PULSEREFERENCE, _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE, _QUAPROGRAM_ANYSTATEMENT, _QUAPROGRAM_AMPMULTIPLIER, _QUAPROGRAM_RAMPTOZEROSTATEMENT, _QUAPROGRAM_RAMPPULSE, _QUAPROGRAM_CHIRP, _QUAPROGRAM_PLAYSTATEMENT, _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT, _QUAPROGRAM_SETDCOFFSETSTATEMENT, _QUAPROGRAM_ZROTATIONSTATEMENT, _QUAPROGRAM_RESETFRAMESTATEMENT, _QUAPROGRAM_ALIGNSTATEMENT, _QUAPROGRAM_MEASUREPROCESS, _QUAPROGRAM_ANALOGMEASUREPROCESS, _QUAPROGRAM_DIGITALMEASUREPROCESS, _QUAPROGRAM_ANALOGPROCESSTARGET, _QUAPROGRAM_ANALOGTIMEDIVISION, _QUAPROGRAM_MEASUREOUTPUT, _QUAPROGRAM_MEASURESTATEMENT, _QUAPROGRAM_WAITSTATEMENT, _QUAPROGRAM_WAITFORTRIGGERSTATEMENT, _QUAPROGRAM_UPDATECORRECTIONSTATEMENT, _QUAPROGRAM_RESETPHASESTATEMENT, _QUAPROGRAM_CORRECTION, _QUAPROGRAM_SYNCSTATEMENT, _QUAPROGRAM_ELSEIF, _QUAPROGRAM_IFSTATEMENT, _QUAPROGRAM_FORSTATEMENT, _QUAPROGRAM_QRUNSTATEMENT, _QUAPROGRAM_FOREACHSTATEMENT, _QUAPROGRAM_RUSSTATEMENT, _QUAPROGRAM_ASSIGNMENTSTATEMENT, _QUAPROGRAM_PAUSESTATEMENT, _QUAPROGRAM_SAVESTATEMENT, _QUAPROGRAM_STATEMENTSCOLLECTION, _QUAPROGRAM_ANYSCALAREXPRESSION, _QUAPROGRAM_LIBFUNCTIONEXPRESSION, _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT, _QUAPROGRAM_ARRAYLENGTHEXPRESSION, _QUAPROGRAM_VARREFEXPRESSION, _QUAPROGRAM_ARRAYVARREFEXPRESSION, _QUAPROGRAM_ARRAYCELLREFEXPRESSION, _QUAPROGRAM_LITERALEXPRESSION, _QUAPROGRAM_BINARYEXPRESSION, _QUAPROGRAM_DYNAMICCONFIG, ],
  enum_types=[
    _QUAPROGRAM_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=14447,
)


_QUARESULTANALYSIS = _descriptor.Descriptor(
  name='QuaResultAnalysis',
  full_name='qm.grpc.qua.QuaResultAnalysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.qua.QuaResultAnalysis.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='qm.grpc.qua.QuaResultAnalysis.model', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14449,
  serialized_end=14528,
)

_QUAPROGRAM_COMPILEROPTIONS.containing_type = _QUAPROGRAM
_QUAPROGRAM_SCRIPT.fields_by_name['variables'].message_type = _QUAPROGRAM_VARDECLARATION
_QUAPROGRAM_SCRIPT.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_SCRIPT.containing_type = _QUAPROGRAM
_QUAPROGRAM_VARDECLARATION.fields_by_name['type'].enum_type = _QUAPROGRAM_TYPE
_QUAPROGRAM_VARDECLARATION.fields_by_name['value'].message_type = _QUAPROGRAM_LITERALEXPRESSION
_QUAPROGRAM_VARDECLARATION.containing_type = _QUAPROGRAM
_QUAPROGRAM_QUANTUMELEMENTREFERENCE.containing_type = _QUAPROGRAM
_QUAPROGRAM_PULSEREFERENCE.containing_type = _QUAPROGRAM
_QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['play'].message_type = _QUAPROGRAM_PLAYSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['measure'].message_type = _QUAPROGRAM_MEASURESTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['wait'].message_type = _QUAPROGRAM_WAITSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['sync'].message_type = _QUAPROGRAM_SYNCSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['if'].message_type = _QUAPROGRAM_IFSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['assign'].message_type = _QUAPROGRAM_ASSIGNMENTSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['for'].message_type = _QUAPROGRAM_FORSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['rus'].message_type = _QUAPROGRAM_RUSSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['align'].message_type = _QUAPROGRAM_ALIGNSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateFrequency'].message_type = _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['zRotation'].message_type = _QUAPROGRAM_ZROTATIONSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['pause'].message_type = _QUAPROGRAM_PAUSESTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['save'].message_type = _QUAPROGRAM_SAVESTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['forEach'].message_type = _QUAPROGRAM_FOREACHSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['waitForTrigger'].message_type = _QUAPROGRAM_WAITFORTRIGGERSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['qrun'].message_type = _QUAPROGRAM_QRUNSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateCorrection'].message_type = _QUAPROGRAM_UPDATECORRECTIONSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetPhase'].message_type = _QUAPROGRAM_RESETPHASESTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['rampToZero'].message_type = _QUAPROGRAM_RAMPTOZEROSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetFrame'].message_type = _QUAPROGRAM_RESETFRAMESTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['setDcOffset'].message_type = _QUAPROGRAM_SETDCOFFSETSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['advanceInputStream'].message_type = _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT
_QUAPROGRAM_ANYSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['play'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['play'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['measure'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['measure'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['wait'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['wait'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['sync'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['sync'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['if'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['if'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['assign'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['assign'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['for'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['for'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['rus'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['rus'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['align'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['align'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateFrequency'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateFrequency'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['zRotation'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['zRotation'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['pause'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['pause'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['save'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['save'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['forEach'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['forEach'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['waitForTrigger'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['waitForTrigger'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['qrun'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['qrun'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateCorrection'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['updateCorrection'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetPhase'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetPhase'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['rampToZero'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['rampToZero'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetFrame'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['resetFrame'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['setDcOffset'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['setDcOffset'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof'].fields.append(
  _QUAPROGRAM_ANYSTATEMENT.fields_by_name['advanceInputStream'])
_QUAPROGRAM_ANYSTATEMENT.fields_by_name['advanceInputStream'].containing_oneof = _QUAPROGRAM_ANYSTATEMENT.oneofs_by_name['statement_oneof']
_QUAPROGRAM_AMPMULTIPLIER.fields_by_name['v0'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_AMPMULTIPLIER.fields_by_name['v1'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_AMPMULTIPLIER.fields_by_name['v2'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_AMPMULTIPLIER.fields_by_name['v3'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_AMPMULTIPLIER.containing_type = _QUAPROGRAM
_QUAPROGRAM_RAMPTOZEROSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_RAMPTOZEROSTATEMENT.fields_by_name['duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUAPROGRAM_RAMPTOZEROSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_RAMPPULSE.fields_by_name['value'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_RAMPPULSE.containing_type = _QUAPROGRAM
_QUAPROGRAM_CHIRP.fields_by_name['scalarRate'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_CHIRP.fields_by_name['arrayRate'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_CHIRP.fields_by_name['units'].enum_type = _QUAPROGRAM_CHIRP_UNITS
_QUAPROGRAM_CHIRP.containing_type = _QUAPROGRAM
_QUAPROGRAM_CHIRP_UNITS.containing_type = _QUAPROGRAM_CHIRP
_QUAPROGRAM_CHIRP.oneofs_by_name['rate'].fields.append(
  _QUAPROGRAM_CHIRP.fields_by_name['scalarRate'])
_QUAPROGRAM_CHIRP.fields_by_name['scalarRate'].containing_oneof = _QUAPROGRAM_CHIRP.oneofs_by_name['rate']
_QUAPROGRAM_CHIRP.oneofs_by_name['rate'].fields.append(
  _QUAPROGRAM_CHIRP.fields_by_name['arrayRate'])
_QUAPROGRAM_CHIRP.fields_by_name['arrayRate'].containing_oneof = _QUAPROGRAM_CHIRP.oneofs_by_name['rate']
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['pulse'].message_type = _QUAPROGRAM_PULSEREFERENCE
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['namedPulse'].message_type = _QUAPROGRAM_PULSEREFERENCE
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['rampPulse'].message_type = _QUAPROGRAM_RAMPPULSE
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['amp'].message_type = _QUAPROGRAM_AMPMULTIPLIER
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['duration'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['condition'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['chirp'].message_type = _QUAPROGRAM_CHIRP
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['truncate'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_PLAYSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_PLAYSTATEMENT.oneofs_by_name['pulseType'].fields.append(
  _QUAPROGRAM_PLAYSTATEMENT.fields_by_name['namedPulse'])
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['namedPulse'].containing_oneof = _QUAPROGRAM_PLAYSTATEMENT.oneofs_by_name['pulseType']
_QUAPROGRAM_PLAYSTATEMENT.oneofs_by_name['pulseType'].fields.append(
  _QUAPROGRAM_PLAYSTATEMENT.fields_by_name['rampPulse'])
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['rampPulse'].containing_oneof = _QUAPROGRAM_PLAYSTATEMENT.oneofs_by_name['pulseType']
_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT.fields_by_name['value'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT.fields_by_name['units'].enum_type = _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS
_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_UPDATEFREQUENCYSTATEMENT_UNITS.containing_type = _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT
_QUAPROGRAM_SETDCOFFSETSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_SETDCOFFSETSTATEMENT.fields_by_name['offset'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_SETDCOFFSETSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ZROTATIONSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_ZROTATIONSTATEMENT.fields_by_name['value'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_ZROTATIONSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_RESETFRAMESTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_RESETFRAMESTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ALIGNSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_ALIGNSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_MEASUREPROCESS.fields_by_name['analog'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_MEASUREPROCESS.fields_by_name['digital'].message_type = _QUAPROGRAM_DIGITALMEASUREPROCESS
_QUAPROGRAM_MEASUREPROCESS.containing_type = _QUAPROGRAM
_QUAPROGRAM_MEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_MEASUREPROCESS.fields_by_name['analog'])
_QUAPROGRAM_MEASUREPROCESS.fields_by_name['analog'].containing_oneof = _QUAPROGRAM_MEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_MEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_MEASUREPROCESS.fields_by_name['digital'])
_QUAPROGRAM_MEASUREPROCESS.fields_by_name['digital'].containing_oneof = _QUAPROGRAM_MEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION.fields_by_name['integration'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION.fields_by_name['target'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION.fields_by_name['integration1'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION.fields_by_name['integration2'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION.fields_by_name['target'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION.fields_by_name['integration'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION.fields_by_name['target'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION.fields_by_name['integration1'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION.fields_by_name['integration2'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION.fields_by_name['target'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING.fields_by_name['target'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING.fields_by_name['targetLen'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING.fields_by_name['target'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING.fields_by_name['targetLen'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING.containing_type = _QUAPROGRAM_ANALOGMEASUREPROCESS
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['bareIntegration'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['demodIntegration'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['rawTimeTagging'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualBareIntegration'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualDemodIntegration'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['highResTimeTagging'].message_type = _QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING
_QUAPROGRAM_ANALOGMEASUREPROCESS.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['bareIntegration'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['bareIntegration'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['demodIntegration'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['demodIntegration'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['rawTimeTagging'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['rawTimeTagging'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualBareIntegration'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualBareIntegration'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualDemodIntegration'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['dualDemodIntegration'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['highResTimeTagging'])
_QUAPROGRAM_ANALOGMEASUREPROCESS.fields_by_name['highResTimeTagging'].containing_oneof = _QUAPROGRAM_ANALOGMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING.fields_by_name['target'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING.fields_by_name['targetLen'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING.containing_type = _QUAPROGRAM_DIGITALMEASUREPROCESS
_QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING.fields_by_name['target'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING.containing_type = _QUAPROGRAM_DIGITALMEASUREPROCESS
_QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['rawTimeTagging'].message_type = _QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING
_QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['counting'].message_type = _QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING
_QUAPROGRAM_DIGITALMEASUREPROCESS.containing_type = _QUAPROGRAM
_QUAPROGRAM_DIGITALMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['rawTimeTagging'])
_QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['rawTimeTagging'].containing_oneof = _QUAPROGRAM_DIGITALMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_DIGITALMEASUREPROCESS.oneofs_by_name['process'].fields.append(
  _QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['counting'])
_QUAPROGRAM_DIGITALMEASUREPROCESS.fields_by_name['counting'].containing_oneof = _QUAPROGRAM_DIGITALMEASUREPROCESS.oneofs_by_name['process']
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['arrayCell'].message_type = _QUAPROGRAM_ARRAYCELLREFEXPRESSION
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.containing_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['variable'])
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['variable'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.oneofs_by_name['target']
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['arrayCell'])
_QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.fields_by_name['arrayCell'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET.oneofs_by_name['target']
_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET.fields_by_name['array'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET.fields_by_name['timeDivision'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION
_QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET.containing_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['sliced'].message_type = _QUAPROGRAM_ANALOGTIMEDIVISION_SLICED
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['accumulated'].message_type = _QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['movingWindow'].message_type = _QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.containing_type = _QUAPROGRAM_ANALOGPROCESSTARGET
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['sliced'])
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['sliced'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision']
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['accumulated'])
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['accumulated'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision']
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['movingWindow'])
_QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.fields_by_name['movingWindow'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION.oneofs_by_name['timeDivision']
_QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['scalarProcess'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET
_QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['vectorProcess'].message_type = _QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET
_QUAPROGRAM_ANALOGPROCESSTARGET.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANALOGPROCESSTARGET.oneofs_by_name['processTarget'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['scalarProcess'])
_QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['scalarProcess'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET.oneofs_by_name['processTarget']
_QUAPROGRAM_ANALOGPROCESSTARGET.oneofs_by_name['processTarget'].fields.append(
  _QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['vectorProcess'])
_QUAPROGRAM_ANALOGPROCESSTARGET.fields_by_name['vectorProcess'].containing_oneof = _QUAPROGRAM_ANALOGPROCESSTARGET.oneofs_by_name['processTarget']
_QUAPROGRAM_ANALOGTIMEDIVISION_SLICED.containing_type = _QUAPROGRAM_ANALOGTIMEDIVISION
_QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED.containing_type = _QUAPROGRAM_ANALOGTIMEDIVISION
_QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW.containing_type = _QUAPROGRAM_ANALOGTIMEDIVISION
_QUAPROGRAM_ANALOGTIMEDIVISION.containing_type = _QUAPROGRAM
_QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['arrayCell'].message_type = _QUAPROGRAM_ARRAYCELLREFEXPRESSION
_QUAPROGRAM_MEASUREOUTPUT_TARGET.containing_type = _QUAPROGRAM_MEASUREOUTPUT
_QUAPROGRAM_MEASUREOUTPUT_TARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['variable'])
_QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['variable'].containing_oneof = _QUAPROGRAM_MEASUREOUTPUT_TARGET.oneofs_by_name['target']
_QUAPROGRAM_MEASUREOUTPUT_TARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['arrayCell'])
_QUAPROGRAM_MEASUREOUTPUT_TARGET.fields_by_name['arrayCell'].containing_oneof = _QUAPROGRAM_MEASUREOUTPUT_TARGET.oneofs_by_name['target']
_QUAPROGRAM_MEASUREOUTPUT.fields_by_name['integration'].message_type = _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE
_QUAPROGRAM_MEASUREOUTPUT.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_MEASUREOUTPUT.fields_by_name['target'].message_type = _QUAPROGRAM_MEASUREOUTPUT_TARGET
_QUAPROGRAM_MEASUREOUTPUT.containing_type = _QUAPROGRAM
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['pulse'].message_type = _QUAPROGRAM_PULSEREFERENCE
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['amp'].message_type = _QUAPROGRAM_AMPMULTIPLIER
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['outputs'].message_type = _QUAPROGRAM_MEASUREOUTPUT
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['measureProcesses'].message_type = _QUAPROGRAM_MEASUREPROCESS
_QUAPROGRAM_MEASURESTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_WAITSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_WAITSTATEMENT.fields_by_name['time'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_WAITSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT.containing_type = _QUAPROGRAM_WAITFORTRIGGERSTATEMENT
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['pulseToPlay'].message_type = _QUAPROGRAM_PULSEREFERENCE
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['globalTrigger'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['elementOutput'].message_type = _QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.oneofs_by_name['source'].fields.append(
  _QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['globalTrigger'])
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['globalTrigger'].containing_oneof = _QUAPROGRAM_WAITFORTRIGGERSTATEMENT.oneofs_by_name['source']
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.oneofs_by_name['source'].fields.append(
  _QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['elementOutput'])
_QUAPROGRAM_WAITFORTRIGGERSTATEMENT.fields_by_name['elementOutput'].containing_oneof = _QUAPROGRAM_WAITFORTRIGGERSTATEMENT.oneofs_by_name['source']
_QUAPROGRAM_UPDATECORRECTIONSTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_UPDATECORRECTIONSTATEMENT.fields_by_name['correction'].message_type = _QUAPROGRAM_CORRECTION
_QUAPROGRAM_UPDATECORRECTIONSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_RESETPHASESTATEMENT.fields_by_name['qe'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_RESETPHASESTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_CORRECTION.fields_by_name['c0'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_CORRECTION.fields_by_name['c1'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_CORRECTION.fields_by_name['c2'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_CORRECTION.fields_by_name['c3'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_CORRECTION.containing_type = _QUAPROGRAM
_QUAPROGRAM_SYNCSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ELSEIF.fields_by_name['condition'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_ELSEIF.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_ELSEIF.containing_type = _QUAPROGRAM
_QUAPROGRAM_IFSTATEMENT.fields_by_name['condition'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_IFSTATEMENT.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_IFSTATEMENT.fields_by_name['else'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_IFSTATEMENT.fields_by_name['elseifs'].message_type = _QUAPROGRAM_ELSEIF
_QUAPROGRAM_IFSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_FORSTATEMENT.fields_by_name['init'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_FORSTATEMENT.fields_by_name['condition'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_FORSTATEMENT.fields_by_name['update'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_FORSTATEMENT.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_FORSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_QRUNSTATEMENT.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_QRUNSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES.fields_by_name['array'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES.containing_type = _QUAPROGRAM_FOREACHSTATEMENT
_QUAPROGRAM_FOREACHSTATEMENT.fields_by_name['iterator'].message_type = _QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES
_QUAPROGRAM_FOREACHSTATEMENT.fields_by_name['body'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_FOREACHSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_RUSSTATEMENT.fields_by_name['doBlock'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_RUSSTATEMENT.fields_by_name['failBlock'].message_type = _QUAPROGRAM_STATEMENTSCOLLECTION
_QUAPROGRAM_RUSSTATEMENT.fields_by_name['until'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_RUSSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['arrayCell'].message_type = _QUAPROGRAM_ARRAYCELLREFEXPRESSION
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.containing_type = _QUAPROGRAM_ASSIGNMENTSTATEMENT
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['variable'])
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['variable'].containing_oneof = _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.oneofs_by_name['target']
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.oneofs_by_name['target'].fields.append(
  _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['arrayCell'])
_QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.fields_by_name['arrayCell'].containing_oneof = _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET.oneofs_by_name['target']
_QUAPROGRAM_ASSIGNMENTSTATEMENT.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ASSIGNMENTSTATEMENT.fields_by_name['expression'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_ASSIGNMENTSTATEMENT.fields_by_name['target'].message_type = _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET
_QUAPROGRAM_ASSIGNMENTSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_PAUSESTATEMENT.fields_by_name['qes'].message_type = _QUAPROGRAM_QUANTUMELEMENTREFERENCE
_QUAPROGRAM_PAUSESTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['arrayCell'].message_type = _QUAPROGRAM_ARRAYCELLREFEXPRESSION
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['literal'].message_type = _QUAPROGRAM_LITERALEXPRESSION
_QUAPROGRAM_SAVESTATEMENT_SOURCE.containing_type = _QUAPROGRAM_SAVESTATEMENT
_QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source'].fields.append(
  _QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['variable'])
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['variable'].containing_oneof = _QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source']
_QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source'].fields.append(
  _QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['arrayCell'])
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['arrayCell'].containing_oneof = _QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source']
_QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source'].fields.append(
  _QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['literal'])
_QUAPROGRAM_SAVESTATEMENT_SOURCE.fields_by_name['literal'].containing_oneof = _QUAPROGRAM_SAVESTATEMENT_SOURCE.oneofs_by_name['source']
_QUAPROGRAM_SAVESTATEMENT.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_SAVESTATEMENT.fields_by_name['source'].message_type = _QUAPROGRAM_SAVESTATEMENT_SOURCE
_QUAPROGRAM_SAVESTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_STATEMENTSCOLLECTION.fields_by_name['statements'].message_type = _QUAPROGRAM_ANYSTATEMENT
_QUAPROGRAM_STATEMENTSCOLLECTION.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['variable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['literal'].message_type = _QUAPROGRAM_LITERALEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['binaryOperation'].message_type = _QUAPROGRAM_BINARYEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayCell'].message_type = _QUAPROGRAM_ARRAYCELLREFEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayLength'].message_type = _QUAPROGRAM_ARRAYLENGTHEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['libFunction'].message_type = _QUAPROGRAM_LIBFUNCTIONEXPRESSION
_QUAPROGRAM_ANYSCALAREXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['variable'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['variable'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['literal'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['literal'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['binaryOperation'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['binaryOperation'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayCell'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayCell'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayLength'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['arrayLength'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof'].fields.append(
  _QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['libFunction'])
_QUAPROGRAM_ANYSCALAREXPRESSION.fields_by_name['libFunction'].containing_oneof = _QUAPROGRAM_ANYSCALAREXPRESSION.oneofs_by_name['expression_oneof']
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['scalar'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['array'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.containing_type = _QUAPROGRAM_LIBFUNCTIONEXPRESSION
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.oneofs_by_name['argument_oneof'].fields.append(
  _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['scalar'])
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['scalar'].containing_oneof = _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.oneofs_by_name['argument_oneof']
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.oneofs_by_name['argument_oneof'].fields.append(
  _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['array'])
_QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.fields_by_name['array'].containing_oneof = _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT.oneofs_by_name['argument_oneof']
_QUAPROGRAM_LIBFUNCTIONEXPRESSION.fields_by_name['arguments'].message_type = _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT
_QUAPROGRAM_LIBFUNCTIONEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamVariable'].message_type = _QUAPROGRAM_VARREFEXPRESSION
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamArray'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.containing_type = _QUAPROGRAM
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.oneofs_by_name['stream_oneof'].fields.append(
  _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamVariable'])
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamVariable'].containing_oneof = _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.oneofs_by_name['stream_oneof']
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.oneofs_by_name['stream_oneof'].fields.append(
  _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamArray'])
_QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.fields_by_name['streamArray'].containing_oneof = _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT.oneofs_by_name['stream_oneof']
_QUAPROGRAM_ARRAYLENGTHEXPRESSION.fields_by_name['array'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ARRAYLENGTHEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_VARREFEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_VARREFEXPRESSION.oneofs_by_name['var_oneof'].fields.append(
  _QUAPROGRAM_VARREFEXPRESSION.fields_by_name['name'])
_QUAPROGRAM_VARREFEXPRESSION.fields_by_name['name'].containing_oneof = _QUAPROGRAM_VARREFEXPRESSION.oneofs_by_name['var_oneof']
_QUAPROGRAM_VARREFEXPRESSION.oneofs_by_name['var_oneof'].fields.append(
  _QUAPROGRAM_VARREFEXPRESSION.fields_by_name['ioNumber'])
_QUAPROGRAM_VARREFEXPRESSION.fields_by_name['ioNumber'].containing_oneof = _QUAPROGRAM_VARREFEXPRESSION.oneofs_by_name['var_oneof']
_QUAPROGRAM_ARRAYVARREFEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_ARRAYCELLREFEXPRESSION.fields_by_name['arrayVar'].message_type = _QUAPROGRAM_ARRAYVARREFEXPRESSION
_QUAPROGRAM_ARRAYCELLREFEXPRESSION.fields_by_name['index'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_ARRAYCELLREFEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_LITERALEXPRESSION.fields_by_name['type'].enum_type = _QUAPROGRAM_TYPE
_QUAPROGRAM_LITERALEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_BINARYEXPRESSION.fields_by_name['op'].enum_type = _QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR
_QUAPROGRAM_BINARYEXPRESSION.fields_by_name['left'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_BINARYEXPRESSION.fields_by_name['right'].message_type = _QUAPROGRAM_ANYSCALAREXPRESSION
_QUAPROGRAM_BINARYEXPRESSION.containing_type = _QUAPROGRAM
_QUAPROGRAM_BINARYEXPRESSION_BINARYOPERATOR.containing_type = _QUAPROGRAM_BINARYEXPRESSION
_QUAPROGRAM_DYNAMICCONFIG.fields_by_name['root'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_QUAPROGRAM_DYNAMICCONFIG.containing_type = _QUAPROGRAM
_QUAPROGRAM.fields_by_name['config'].message_type = qm_dot_pb_dot_inc__qua__config__pb2._QUACONFIG
_QUAPROGRAM.fields_by_name['dynConfig'].message_type = _QUAPROGRAM_DYNAMICCONFIG
_QUAPROGRAM.fields_by_name['script'].message_type = _QUAPROGRAM_SCRIPT
_QUAPROGRAM.fields_by_name['compilerOptions'].message_type = _QUAPROGRAM_COMPILEROPTIONS
_QUAPROGRAM.fields_by_name['resultAnalysis'].message_type = _QUARESULTANALYSIS
_QUAPROGRAM_TYPE.containing_type = _QUAPROGRAM
_QUARESULTANALYSIS.fields_by_name['model'].message_type = google_dot_protobuf_dot_struct__pb2._LISTVALUE
DESCRIPTOR.message_types_by_name['QuaProgram'] = _QUAPROGRAM
DESCRIPTOR.message_types_by_name['QuaResultAnalysis'] = _QUARESULTANALYSIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuaProgram = _reflection.GeneratedProtocolMessageType('QuaProgram', (_message.Message,), {

  'CompilerOptions' : _reflection.GeneratedProtocolMessageType('CompilerOptions', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_COMPILEROPTIONS,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.CompilerOptions)
    })
  ,

  'Script' : _reflection.GeneratedProtocolMessageType('Script', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_SCRIPT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.Script)
    })
  ,

  'VarDeclaration' : _reflection.GeneratedProtocolMessageType('VarDeclaration', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_VARDECLARATION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.VarDeclaration)
    })
  ,

  'QuantumElementReference' : _reflection.GeneratedProtocolMessageType('QuantumElementReference', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_QUANTUMELEMENTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.QuantumElementReference)
    })
  ,

  'PulseReference' : _reflection.GeneratedProtocolMessageType('PulseReference', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_PULSEREFERENCE,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.PulseReference)
    })
  ,

  'IntegrationWeightReference' : _reflection.GeneratedProtocolMessageType('IntegrationWeightReference', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_INTEGRATIONWEIGHTREFERENCE,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.IntegrationWeightReference)
    })
  ,

  'AnyStatement' : _reflection.GeneratedProtocolMessageType('AnyStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ANYSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnyStatement)
    })
  ,

  'AmpMultiplier' : _reflection.GeneratedProtocolMessageType('AmpMultiplier', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_AMPMULTIPLIER,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AmpMultiplier)
    })
  ,

  'RampToZeroStatement' : _reflection.GeneratedProtocolMessageType('RampToZeroStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_RAMPTOZEROSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.RampToZeroStatement)
    })
  ,

  'RampPulse' : _reflection.GeneratedProtocolMessageType('RampPulse', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_RAMPPULSE,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.RampPulse)
    })
  ,

  'Chirp' : _reflection.GeneratedProtocolMessageType('Chirp', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_CHIRP,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.Chirp)
    })
  ,

  'PlayStatement' : _reflection.GeneratedProtocolMessageType('PlayStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_PLAYSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.PlayStatement)
    })
  ,

  'UpdateFrequencyStatement' : _reflection.GeneratedProtocolMessageType('UpdateFrequencyStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_UPDATEFREQUENCYSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.UpdateFrequencyStatement)
    })
  ,

  'SetDcOffsetStatement' : _reflection.GeneratedProtocolMessageType('SetDcOffsetStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_SETDCOFFSETSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.SetDcOffsetStatement)
    })
  ,

  'ZRotationStatement' : _reflection.GeneratedProtocolMessageType('ZRotationStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ZROTATIONSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ZRotationStatement)
    })
  ,

  'ResetFrameStatement' : _reflection.GeneratedProtocolMessageType('ResetFrameStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_RESETFRAMESTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ResetFrameStatement)
    })
  ,

  'AlignStatement' : _reflection.GeneratedProtocolMessageType('AlignStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ALIGNSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AlignStatement)
    })
  ,

  'MeasureProcess' : _reflection.GeneratedProtocolMessageType('MeasureProcess', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_MEASUREPROCESS,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.MeasureProcess)
    })
  ,

  'AnalogMeasureProcess' : _reflection.GeneratedProtocolMessageType('AnalogMeasureProcess', (_message.Message,), {

    'BareIntegration' : _reflection.GeneratedProtocolMessageType('BareIntegration', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_BAREINTEGRATION,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.BareIntegration)
      })
    ,

    'DualBareIntegration' : _reflection.GeneratedProtocolMessageType('DualBareIntegration', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALBAREINTEGRATION,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualBareIntegration)
      })
    ,

    'DemodIntegration' : _reflection.GeneratedProtocolMessageType('DemodIntegration', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_DEMODINTEGRATION,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DemodIntegration)
      })
    ,

    'DualDemodIntegration' : _reflection.GeneratedProtocolMessageType('DualDemodIntegration', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_DUALDEMODINTEGRATION,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.DualDemodIntegration)
      })
    ,

    'RawTimeTagging' : _reflection.GeneratedProtocolMessageType('RawTimeTagging', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_RAWTIMETAGGING,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.RawTimeTagging)
      })
    ,

    'HighResTimeTagging' : _reflection.GeneratedProtocolMessageType('HighResTimeTagging', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS_HIGHRESTIMETAGGING,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess.HighResTimeTagging)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_ANALOGMEASUREPROCESS,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogMeasureProcess)
    })
  ,

  'DigitalMeasureProcess' : _reflection.GeneratedProtocolMessageType('DigitalMeasureProcess', (_message.Message,), {

    'RawTimeTagging' : _reflection.GeneratedProtocolMessageType('RawTimeTagging', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_DIGITALMEASUREPROCESS_RAWTIMETAGGING,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.DigitalMeasureProcess.RawTimeTagging)
      })
    ,

    'Counting' : _reflection.GeneratedProtocolMessageType('Counting', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_DIGITALMEASUREPROCESS_COUNTING,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.DigitalMeasureProcess.Counting)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_DIGITALMEASUREPROCESS,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.DigitalMeasureProcess)
    })
  ,

  'AnalogProcessTarget' : _reflection.GeneratedProtocolMessageType('AnalogProcessTarget', (_message.Message,), {

    'ScalarProcessTarget' : _reflection.GeneratedProtocolMessageType('ScalarProcessTarget', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGPROCESSTARGET_SCALARPROCESSTARGET,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogProcessTarget.ScalarProcessTarget)
      })
    ,

    'VectorProcessTarget' : _reflection.GeneratedProtocolMessageType('VectorProcessTarget', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGPROCESSTARGET_VECTORPROCESSTARGET,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogProcessTarget.VectorProcessTarget)
      })
    ,

    'TimeDivision' : _reflection.GeneratedProtocolMessageType('TimeDivision', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGPROCESSTARGET_TIMEDIVISION,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogProcessTarget.TimeDivision)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_ANALOGPROCESSTARGET,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogProcessTarget)
    })
  ,

  'AnalogTimeDivision' : _reflection.GeneratedProtocolMessageType('AnalogTimeDivision', (_message.Message,), {

    'Sliced' : _reflection.GeneratedProtocolMessageType('Sliced', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGTIMEDIVISION_SLICED,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogTimeDivision.Sliced)
      })
    ,

    'Accumulated' : _reflection.GeneratedProtocolMessageType('Accumulated', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGTIMEDIVISION_ACCUMULATED,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogTimeDivision.Accumulated)
      })
    ,

    'MovingWindow' : _reflection.GeneratedProtocolMessageType('MovingWindow', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ANALOGTIMEDIVISION_MOVINGWINDOW,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogTimeDivision.MovingWindow)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_ANALOGTIMEDIVISION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnalogTimeDivision)
    })
  ,

  'MeasureOutput' : _reflection.GeneratedProtocolMessageType('MeasureOutput', (_message.Message,), {

    'Target' : _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_MEASUREOUTPUT_TARGET,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.MeasureOutput.Target)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_MEASUREOUTPUT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.MeasureOutput)
    })
  ,

  'MeasureStatement' : _reflection.GeneratedProtocolMessageType('MeasureStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_MEASURESTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.MeasureStatement)
    })
  ,

  'WaitStatement' : _reflection.GeneratedProtocolMessageType('WaitStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_WAITSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.WaitStatement)
    })
  ,

  'WaitForTriggerStatement' : _reflection.GeneratedProtocolMessageType('WaitForTriggerStatement', (_message.Message,), {

    'ElementOutput' : _reflection.GeneratedProtocolMessageType('ElementOutput', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_WAITFORTRIGGERSTATEMENT_ELEMENTOUTPUT,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.WaitForTriggerStatement.ElementOutput)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_WAITFORTRIGGERSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.WaitForTriggerStatement)
    })
  ,

  'UpdateCorrectionStatement' : _reflection.GeneratedProtocolMessageType('UpdateCorrectionStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_UPDATECORRECTIONSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.UpdateCorrectionStatement)
    })
  ,

  'ResetPhaseStatement' : _reflection.GeneratedProtocolMessageType('ResetPhaseStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_RESETPHASESTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ResetPhaseStatement)
    })
  ,

  'Correction' : _reflection.GeneratedProtocolMessageType('Correction', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_CORRECTION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.Correction)
    })
  ,

  'SyncStatement' : _reflection.GeneratedProtocolMessageType('SyncStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_SYNCSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.SyncStatement)
    })
  ,

  'ElseIf' : _reflection.GeneratedProtocolMessageType('ElseIf', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ELSEIF,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ElseIf)
    })
  ,

  'IfStatement' : _reflection.GeneratedProtocolMessageType('IfStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_IFSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.IfStatement)
    })
  ,

  'ForStatement' : _reflection.GeneratedProtocolMessageType('ForStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_FORSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ForStatement)
    })
  ,

  'QRunStatement' : _reflection.GeneratedProtocolMessageType('QRunStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_QRUNSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.QRunStatement)
    })
  ,

  'ForEachStatement' : _reflection.GeneratedProtocolMessageType('ForEachStatement', (_message.Message,), {

    'VariableWithValues' : _reflection.GeneratedProtocolMessageType('VariableWithValues', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_FOREACHSTATEMENT_VARIABLEWITHVALUES,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ForEachStatement.VariableWithValues)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_FOREACHSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ForEachStatement)
    })
  ,

  'RusStatement' : _reflection.GeneratedProtocolMessageType('RusStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_RUSSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.RusStatement)
    })
  ,

  'AssignmentStatement' : _reflection.GeneratedProtocolMessageType('AssignmentStatement', (_message.Message,), {

    'Target' : _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_ASSIGNMENTSTATEMENT_TARGET,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AssignmentStatement.Target)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_ASSIGNMENTSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AssignmentStatement)
    })
  ,

  'PauseStatement' : _reflection.GeneratedProtocolMessageType('PauseStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_PAUSESTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.PauseStatement)
    })
  ,

  'SaveStatement' : _reflection.GeneratedProtocolMessageType('SaveStatement', (_message.Message,), {

    'Source' : _reflection.GeneratedProtocolMessageType('Source', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_SAVESTATEMENT_SOURCE,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.SaveStatement.Source)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_SAVESTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.SaveStatement)
    })
  ,

  'StatementsCollection' : _reflection.GeneratedProtocolMessageType('StatementsCollection', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_STATEMENTSCOLLECTION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.StatementsCollection)
    })
  ,

  'AnyScalarExpression' : _reflection.GeneratedProtocolMessageType('AnyScalarExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ANYSCALAREXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AnyScalarExpression)
    })
  ,

  'LibFunctionExpression' : _reflection.GeneratedProtocolMessageType('LibFunctionExpression', (_message.Message,), {

    'Argument' : _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), {
      'DESCRIPTOR' : _QUAPROGRAM_LIBFUNCTIONEXPRESSION_ARGUMENT,
      '__module__' : 'qm.pb.inc_qua_pb2'
      # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.LibFunctionExpression.Argument)
      })
    ,
    'DESCRIPTOR' : _QUAPROGRAM_LIBFUNCTIONEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.LibFunctionExpression)
    })
  ,

  'AdvanceInputStreamStatement' : _reflection.GeneratedProtocolMessageType('AdvanceInputStreamStatement', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ADVANCEINPUTSTREAMSTATEMENT,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.AdvanceInputStreamStatement)
    })
  ,

  'ArrayLengthExpression' : _reflection.GeneratedProtocolMessageType('ArrayLengthExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ARRAYLENGTHEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ArrayLengthExpression)
    })
  ,

  'VarRefExpression' : _reflection.GeneratedProtocolMessageType('VarRefExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_VARREFEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.VarRefExpression)
    })
  ,

  'ArrayVarRefExpression' : _reflection.GeneratedProtocolMessageType('ArrayVarRefExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ARRAYVARREFEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ArrayVarRefExpression)
    })
  ,

  'ArrayCellRefExpression' : _reflection.GeneratedProtocolMessageType('ArrayCellRefExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_ARRAYCELLREFEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.ArrayCellRefExpression)
    })
  ,

  'LiteralExpression' : _reflection.GeneratedProtocolMessageType('LiteralExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_LITERALEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.LiteralExpression)
    })
  ,

  'BinaryExpression' : _reflection.GeneratedProtocolMessageType('BinaryExpression', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_BINARYEXPRESSION,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.BinaryExpression)
    })
  ,

  'DynamicConfig' : _reflection.GeneratedProtocolMessageType('DynamicConfig', (_message.Message,), {
    'DESCRIPTOR' : _QUAPROGRAM_DYNAMICCONFIG,
    '__module__' : 'qm.pb.inc_qua_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram.DynamicConfig)
    })
  ,
  'DESCRIPTOR' : _QUAPROGRAM,
  '__module__' : 'qm.pb.inc_qua_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaProgram)
  })
_sym_db.RegisterMessage(QuaProgram)
_sym_db.RegisterMessage(QuaProgram.CompilerOptions)
_sym_db.RegisterMessage(QuaProgram.Script)
_sym_db.RegisterMessage(QuaProgram.VarDeclaration)
_sym_db.RegisterMessage(QuaProgram.QuantumElementReference)
_sym_db.RegisterMessage(QuaProgram.PulseReference)
_sym_db.RegisterMessage(QuaProgram.IntegrationWeightReference)
_sym_db.RegisterMessage(QuaProgram.AnyStatement)
_sym_db.RegisterMessage(QuaProgram.AmpMultiplier)
_sym_db.RegisterMessage(QuaProgram.RampToZeroStatement)
_sym_db.RegisterMessage(QuaProgram.RampPulse)
_sym_db.RegisterMessage(QuaProgram.Chirp)
_sym_db.RegisterMessage(QuaProgram.PlayStatement)
_sym_db.RegisterMessage(QuaProgram.UpdateFrequencyStatement)
_sym_db.RegisterMessage(QuaProgram.SetDcOffsetStatement)
_sym_db.RegisterMessage(QuaProgram.ZRotationStatement)
_sym_db.RegisterMessage(QuaProgram.ResetFrameStatement)
_sym_db.RegisterMessage(QuaProgram.AlignStatement)
_sym_db.RegisterMessage(QuaProgram.MeasureProcess)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.BareIntegration)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.DualBareIntegration)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.DemodIntegration)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.DualDemodIntegration)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.RawTimeTagging)
_sym_db.RegisterMessage(QuaProgram.AnalogMeasureProcess.HighResTimeTagging)
_sym_db.RegisterMessage(QuaProgram.DigitalMeasureProcess)
_sym_db.RegisterMessage(QuaProgram.DigitalMeasureProcess.RawTimeTagging)
_sym_db.RegisterMessage(QuaProgram.DigitalMeasureProcess.Counting)
_sym_db.RegisterMessage(QuaProgram.AnalogProcessTarget)
_sym_db.RegisterMessage(QuaProgram.AnalogProcessTarget.ScalarProcessTarget)
_sym_db.RegisterMessage(QuaProgram.AnalogProcessTarget.VectorProcessTarget)
_sym_db.RegisterMessage(QuaProgram.AnalogProcessTarget.TimeDivision)
_sym_db.RegisterMessage(QuaProgram.AnalogTimeDivision)
_sym_db.RegisterMessage(QuaProgram.AnalogTimeDivision.Sliced)
_sym_db.RegisterMessage(QuaProgram.AnalogTimeDivision.Accumulated)
_sym_db.RegisterMessage(QuaProgram.AnalogTimeDivision.MovingWindow)
_sym_db.RegisterMessage(QuaProgram.MeasureOutput)
_sym_db.RegisterMessage(QuaProgram.MeasureOutput.Target)
_sym_db.RegisterMessage(QuaProgram.MeasureStatement)
_sym_db.RegisterMessage(QuaProgram.WaitStatement)
_sym_db.RegisterMessage(QuaProgram.WaitForTriggerStatement)
_sym_db.RegisterMessage(QuaProgram.WaitForTriggerStatement.ElementOutput)
_sym_db.RegisterMessage(QuaProgram.UpdateCorrectionStatement)
_sym_db.RegisterMessage(QuaProgram.ResetPhaseStatement)
_sym_db.RegisterMessage(QuaProgram.Correction)
_sym_db.RegisterMessage(QuaProgram.SyncStatement)
_sym_db.RegisterMessage(QuaProgram.ElseIf)
_sym_db.RegisterMessage(QuaProgram.IfStatement)
_sym_db.RegisterMessage(QuaProgram.ForStatement)
_sym_db.RegisterMessage(QuaProgram.QRunStatement)
_sym_db.RegisterMessage(QuaProgram.ForEachStatement)
_sym_db.RegisterMessage(QuaProgram.ForEachStatement.VariableWithValues)
_sym_db.RegisterMessage(QuaProgram.RusStatement)
_sym_db.RegisterMessage(QuaProgram.AssignmentStatement)
_sym_db.RegisterMessage(QuaProgram.AssignmentStatement.Target)
_sym_db.RegisterMessage(QuaProgram.PauseStatement)
_sym_db.RegisterMessage(QuaProgram.SaveStatement)
_sym_db.RegisterMessage(QuaProgram.SaveStatement.Source)
_sym_db.RegisterMessage(QuaProgram.StatementsCollection)
_sym_db.RegisterMessage(QuaProgram.AnyScalarExpression)
_sym_db.RegisterMessage(QuaProgram.LibFunctionExpression)
_sym_db.RegisterMessage(QuaProgram.LibFunctionExpression.Argument)
_sym_db.RegisterMessage(QuaProgram.AdvanceInputStreamStatement)
_sym_db.RegisterMessage(QuaProgram.ArrayLengthExpression)
_sym_db.RegisterMessage(QuaProgram.VarRefExpression)
_sym_db.RegisterMessage(QuaProgram.ArrayVarRefExpression)
_sym_db.RegisterMessage(QuaProgram.ArrayCellRefExpression)
_sym_db.RegisterMessage(QuaProgram.LiteralExpression)
_sym_db.RegisterMessage(QuaProgram.BinaryExpression)
_sym_db.RegisterMessage(QuaProgram.DynamicConfig)

QuaResultAnalysis = _reflection.GeneratedProtocolMessageType('QuaResultAnalysis', (_message.Message,), {
  'DESCRIPTOR' : _QUARESULTANALYSIS,
  '__module__' : 'qm.pb.inc_qua_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qua.QuaResultAnalysis)
  })
_sym_db.RegisterMessage(QuaResultAnalysis)


DESCRIPTOR._options = None
_QUAPROGRAM_COMPILEROPTIONS.fields_by_name['useExperimentalCalculationCompiler']._options = None
_QUAPROGRAM_COMPILEROPTIONS.fields_by_name['optimizeMergeCodeExecution']._options = None
_QUAPROGRAM_COMPILEROPTIONS.fields_by_name['optimizeWriteReadCommands']._options = None
_QUAPROGRAM_COMPILEROPTIONS.fields_by_name['skipOptimizations']._options = None
_QUAPROGRAM_COMPILEROPTIONS.fields_by_name['strict']._options = None
_QUAPROGRAM_PLAYSTATEMENT.fields_by_name['pulse']._options = None
_QUAPROGRAM_MEASUREOUTPUT.fields_by_name['variable']._options = None
_QUAPROGRAM_MEASURESTATEMENT.fields_by_name['outputs']._options = None
_QUAPROGRAM_ASSIGNMENTSTATEMENT.fields_by_name['variable']._options = None
_QUAPROGRAM_ASSIGNMENTSTATEMENT.fields_by_name['save']._options = None
_QUAPROGRAM_SAVESTATEMENT.fields_by_name['variable']._options = None
# @@protoc_insertion_point(module_scope)
